Struct DispatchQueue
pub struct DispatchQueue { /* private fields */ }Expand description
A wrapper around GCD DispatchQueue
This allows you to provide a custom dispatch queue for stream output handling instead of using the default queue.
Example
use apple_cf::dispatch_queue::{DispatchQueue, DispatchQoS};
let queue = DispatchQueue::new("com.myapp.capture", DispatchQoS::UserInteractive);Implementations
impl DispatchQueue
impl DispatchQueue
pub fn new(label: &str, qos: DispatchQoS) -> DispatchQueue
pub fn new(label: &str, qos: DispatchQoS) -> DispatchQueue
Creates a new dispatch queue with the specified label and QoS
Arguments
label- A string label for the queue (e.g., “com.myapp.capture”)qos- The quality of service level for the queue
Examples
use apple_cf::dispatch_queue::{DispatchQueue, DispatchQoS};
let queue = DispatchQueue::new("com.myapp.capture", DispatchQoS::UserInteractive);
// Use the queue with SCStream's add_output_handler_with_queuePanics
Panics if the label contains null bytes or if queue creation fails